summaryrefslogtreecommitdiffstats
path: root/kdejava/koala/test/kbase/KBase.java
diff options
context:
space:
mode:
Diffstat (limited to 'kdejava/koala/test/kbase/KBase.java')
-rw-r--r--kdejava/koala/test/kbase/KBase.java12
1 files changed, 6 insertions, 6 deletions
diff --git a/kdejava/koala/test/kbase/KBase.java b/kdejava/koala/test/kbase/KBase.java
index ed584dcd..6401dd80 100644
--- a/kdejava/koala/test/kbase/KBase.java
+++ b/kdejava/koala/test/kbase/KBase.java
@@ -11,7 +11,7 @@ import org.kde.koala.*;
* KBase reimplements the methods that KMainWindow provides for main window handling and supports
* full session management as well as using KActions.
* @see KMainWindow
- * @see KApplication
+ * @see TDEApplication
* @see KConfig
*
* @author Source Framework Automatically Generated by KDevelop, (c) The KDevelop Team.
@@ -55,7 +55,7 @@ public class KBase extends KMainWindow
public KBase(TQWidget parent, String name)
{
super(parent, name, 0);
- KApplication kapp = KApplication.kApplication();
+ TDEApplication kapp = TDEApplication.kApplication();
config=kapp.config();
///////////////////////////////////////////////////////////////////
@@ -230,7 +230,7 @@ protected void readOptions()
}
/** saves the window properties for each open window during session end to the session config file, including saving the currently
* opened file by a temporary filename provided by KApplication.
* @see KTMainWindow#saveProperties
*/
protected void saveProperties(KConfig _cfg)
@@ -245,7 +245,7 @@ protected void saveProperties(KConfig _cfg)
KURL url=doc.URL();
_cfg.writeEntry("filename", url.url());
_cfg.writeEntry("modified", doc.isModified());
- String tempname = KApplication.kApplication().tempSaveName(url.url());
+ String tempname = TDEApplication.kApplication().tempSaveName(url.url());
String tempurl= KURL.encode_string(tempname, 0);
KURL _url = new KURL(tempurl);
doc.saveDocument(_url);
@@ -265,7 +265,7 @@ protected void readProperties(KConfig _cfg)
if(modified)
{
boolean canRecover = false;
- String tempname = KApplication.kApplication().checkRecoverFile(filename, canRecover);
+ String tempname = TDEApplication.kApplication().checkRecoverFile(filename, canRecover);
KURL _url = new KURL(tempname);
if(canRecover)
@@ -561,7 +561,7 @@ public static void main(String[] cmdLineArgs)
KCmdLineArgs.init( cmdLineArgs, aboutData );
KCmdLineArgs.addCmdLineOptions( options ); // Add our own options.
- KApplication app = new KApplication();
+ TDEApplication app = new TDEApplication();
if (app.isRestored())
{
@@ -230,7 +230,7 @@ protected void readOptions()
}
/** saves the window properties for each open window during session end to the session config file, including saving the currently
- * opened file by a temporary filename provided by KApplication.
+ * opened file by a temporary filename provided by TDEApplication.
* @see KTMainWindow#saveProperties
*/